/*!
The data processing module, which implements algorithm related to visualization of data.
Such as, down-sampling, etc.
*/
/*use std::marker::PhantomData;
use crate::drawing::backend::DrawingBackend;
use crate::drawing::coord::RangedCoord;
use crate::chart::ChartContext;*/
